import { CamelCased } from './types';
/**
 * @example ```
 *
 *  const mapUser = autoCamelCaseWithRules({
 *    id: 'userId',
 *  } as const);
 *
 *  const result = mapUser({
 *    id: 1,
 *    ['do you.like__candy']: true,
 *    created_at: new Date()
 *  });  // result: { userId: 1, doYouLikeCandy: true, createdAt: '2021-05-15T21:57:00.524Z' };
 *
 * ````
 */
declare const autoCamelCaseWithCustomRules: <TMap extends Record<PropertyKey, PropertyKey>>(map: Readonly<TMap>) => <TData>(data: TData) => CamelCased<TMap, TData>;
export default autoCamelCaseWithCustomRules;
